from . import *
__copyright__    = 'Copyright (C) 2021 inovue'
__version__      = '1.0.0'
__license__      = 'BSD-3-Clause'
__author__       = 'inovue'
__author_email__ = 'info@inovue.com'
__url__          = 'http://github.com/inovue/chrofile'

#__all__ = []